Glossary
--------

.. glossary::
    Assignment
        A statement that assigns a value to a variable.

    Concatenate
        To join two operands end to end.

    Comment
        Information in a program that is meant for other programmers (or
        anyone reading the source code) and has no effect on the execution
        of the program.

    Evaluate
        To simplify an expression by performing the operations in order to yield a single value.

    Expression
        A combination of variables, operators, and values that represents a
        single result value.

    Floating Point
        A type that represents numbers with fractional parts.

    Integer
        A type that represents whole numbers.

    Keyword
        A reserved word that is used by the compiler to parse a program; you
        cannot use keywords like ``if``, ``def``, and
        ``while`` as variable names.

    Mnemonic
        A memory aid. We often give variables mnemonic names to help us
        remember what is stored in the variable.

    Modulus Operator
        An operator, denoted with a percent sign (``%``), that
        works on integers and yields the remainder when one number is
        divided by another.

    Operand
        One of the values on which an operator operates.

    Operator
        A special symbol that represents a simple computation like addition,
        multiplication, or string concatenation.

    Rules of Precedence
        The set of rules governing the order in which expressions involving
        multiple operators and operands are evaluated.

    Statement
        A section of code that represents a command or action. So far, the
        statements we have seen are assignments and print expression statement.

    String
        A type that represents sequences of characters.

    Type
        A category of values. The types we have seen so far are integers
        (type ``int``), floating-point numbers (type
        ``float``), and strings (type ``str``).

    Value
        One of the basic units of data, like a number or string, that a
        program manipulates.

    Variable
        A name that refers to a value.

.. dragndrop:: varGlossary1
    :practice: T
    :feedback: Look above for these terms.
    :match_1: floating point|||A type that represents numbers with fractional parts.
    :match_2: integer|||A type that represents whole numbers.
    :match_3: string|||A type that represents sequences of characters.
    :match_4: type|||A category of values such as integers (type ``int``\ ), floating-point numbers (type ``float``\ ), and strings (type ``str``\ ).

    Match each term with its definition.

.. dragndrop:: varGlossary2
    :practice: T
    :feedback: Look above for these terms.
    :match_1: assignment|||A statement that assigns a value to a variable.
    :match_2: keyword|||A reserved word that is used by the compiler to parse a program; you cannot use keywords like ``if``\ , ``def``\ , and ``while`` as variable names.
    :match_3: mnemonic|||A memory aid. We often give variables mnemonic names to help us remember what is stored in the variable.
    :match_4: value|||One of the basic units of data, like a number or string, that a program manipulates.
    :match_5: variable|||A name that refers to a value.

    Match each term with its definition.

.. dragndrop:: varGlossary3
    :practice: T
    :feedback: Look above for these terms.
    :match_1: expression|||A combination of variables, operators, and values that represents a single result value.
    :match_2: modulus operator|||An operator, denoted with a percent sign (%), that works on integers and yields the remainder when one number is divided by another.
    :match_3: operand|||One of the values on which an operator operates.
    :match_4: operator|||A special symbol that represents a simple computation like addition, multiplication, or string concatenation.
    :match_5: rules of precedence|||The set of rules governing the order in which expressions involving multiple operators and operands are evaluated.

    Match each term with its definition.

.. dragndrop:: varGlossary4
    :practice: T
    :feedback: Look above for these terms.
    :match_1: concatenate|||To join two operands end to end.
    :match_2: comment|||Information in a program that is meant for other programmers (or anyone reading the source code) and has no effect on the execution of the program.
    :match_3: evaluate|||To simplify an expression by performing the operations in order to yield a single value.
    :match_4: statement|||A section of code that represents a command or action. So far, the statements we have seen are assignments and print expression statement.

    Match each term with its definition.
